### startMyAlgorithm.R: Templated for the interface between SPOT and your algorithm
### to be modified according the commands given at pos. 1,2, and 3.
### Replace "vara" and "VARA", "varb" and "VARB" etc. with variable 
### names of your algorithm (specified in the ROI file).
### Define the call string (replaec "myAlgorithm" with the name of your algorithm.
startMyAlgorithm <- function(io.apdFileName
		, io.desFileName
		, io.resFileName){
	## read default problem design
	source(io.apdFileName,local=TRUE)
	## read doe/dace etc settings:
	print(io.desFileName)
	des <- read.table(io.desFileName
			, sep=" "
			, header = TRUE
	);
	config<-nrow(des);
	attach(des)	
	for (k in 1:config){
		if(des$REPEATS[k]>=1){
			for (i in 1:des$REPEATS[k]){
				### 1. Add user defined parameters here: 
				if (exists("VARA")){
					vara <- des$VARA[k]
				}
				if (exists("VARB")){
					varb <- des$VARB[k]
				}
				## End of user defined section.				
				conf <- k
				if (exists("CONFIG")){
					conf <- des$CONFIG[k]
				}
				spotStep<-NA
				if (exists("STEP")){
					spotStep <- des$STEP[k]
				}
				seed <- des$SEED[k]+i
				### 2. The call string has to be modified by the user:			
				callString <- paste("myAlgorithm", vara, varb, sep = " ")
				### End of user defined call string.
				y <-system(callString, intern= TRUE)
				res <- NULL
				res <- list(Y=y,
						### 3. User specific parameter values have to be added to the list:  
						VARA=vara,
						VARB=varb,												
						### End of user specific parameter values.
						Function=f,
						EVALS=evals,
						D=d,
						SEED=seed,
						CONFIG=conf
				)
				if (exists("STEP")){
					res=c(res,STEP=spotStep)
				} 
				res <-data.frame(res)
				colNames = TRUE
				if (file.exists(io.resFileName)){
					colNames = FALSE
				}
				## quote = false is required for JAVA
				write.table(res
						, file = io.resFileName
						, row.names = FALSE
						, col.names = colNames
						, sep = " "              
						, append = !colNames
						, quote = FALSE
				);		
				colNames = FALSE
			} # end for i
		} # end if(des$REPEATS[k]>=1)
	}	#end for k
	detach(des)
}
